(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     78007,       2754]*)
(*NotebookOutlinePosition[    120274,       4262]*)
(*  CellTagsIndexPosition[    119974,       4249]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[ValueBox["FileName"]], "Title",
  CounterAssignments->{{"Title", 20}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell["\<\
Who asks:\t16.  7.2002\tNorbert S\[UDoubleDot]dland
Handling:\t16.  7.2002 - 16.  4.2003\tNorbert S\[UDoubleDot]dland
Last Calculation:\t16.  4.2003\tNorbert S\[UDoubleDot]dland\
\>", "Subsubtitle",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Problem"
}], "Section"],

Cell[TextData[{
  "The nature of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function shall be better understood."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Answer"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Preparation"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Rule ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]]
}], "Subsubsection"],

Cell[TextData[{
  "The product of two power terms eventually can be simplified if the powers \
are equivalent. A change of the function ",
  Cell[BoxData[
      \(TraditionalForm\`Times[\ ]\)]],
  " usually causes unknown side effects, thus a transformation rule ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]],
  " is created which causes the simplification at an explicit order only:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[TimesRule]; \n
    \(Function[\n\tClear[TimesRule]\ ; \n\t\n\t
        TimesRule::usage = \n\t\t
          "\<TimesRule is a Rule adding some properties to Times where \
needed.\>"\ ; \n\t\n\t
        TimesRule
           = {\n\t\t
             (********************************************************) \n
            \t\t\tTimes[Power[term1_, pow_], Power[term2_, pow_], term3_.] /; 
                \n\t\t\t\t
                Simplify[term1\ term2]\ \  =!= \ \ \((term1\ term2)\) :> \n
              \t\t (********************************************************) 
                \n\t\tterm3\ PowerExpand[Simplify[term1\ term2]^pow]\ , \n\t\t
            \n\t\t (********************************************************) 
              \n\t\t\tTimes[Power[term1_, pow_], Power[term2_, pow_], term3_.]
                   /; \n\t\t\t\t
                ExpandAll[term1\ term2]\ \ \  =!= \ \ \ \((term1\ term2)\) :> 
              \n\t\t (********************************************************\
) \n\t\tterm3\ PowerExpand[ExpandAll[term1\ term2]^pow]\n\t}\ ; \n\t\n\t
        Protect[#]\n]\)[Unprotect[TimesRule]]\)], "Input"],

Cell[BoxData[
    \({"TimesRule"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.00 this property has not yet been implemented thus leading to surprises \
e.g. at the checking calculation about cubic equations."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Function ",
  Cell[BoxData[
      \(TraditionalForm\`LogSimplify[\ ]\)]]
}], "Subsubsection"],

Cell["\<\
A special routine is necessary to simplify logarithmic terms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[LogSimplify]; \n
    \(Function[\n\tClear[LogSimplify]; \n\t\n\t
        LogSimplify::usage = \n\t\t
          "\<LogSimplify[expr] applies `LogSimplifyRules` to `expr`.\>"; \n\n
        \t (*********************) \n\t\t
        LogSimplify[expr_] := \n\t (*********************) \n\t
          expr //. LogSimplifyRules; \n\t\n\tProtect[#]\n]\)[
      Unprotect[LogSimplify]]\)], "Input"],

Cell[BoxData[
    \({"LogSimplify"}\)], "Output"]
}, Open  ]],

Cell["This routine makes use of the following replacing rules:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[LogSimplifyRules]; \n
    \(Function[\n\tClear[LogSimplifyRules]; \n\t\n\t
        LogSimplifyRules::usage = \n\t\t
          "\<LogSimplifyRules is a connection of Rules\>"\ <>\n\t\t\t\ 
            "\< simplfying expressions containing logarithmic terms.\>"; \n\t
        \n\t (********************) \n\t\t
        LogSimplifyRules\  = \n\t (********************) \n
          \t{\t\t\n\t\t (*************************) \n\t\t\t
            c_.\ Log[a_] + c_.  Log[b_] :> \n\t\t
               (*************************) \n\t\tc\ Log[a\ b]\ , \n\t\n\t\t
             (*************) \n\t\t\t
            a_\ Log[b_] :> \n\t\t (*************) \n\t\t
              Log[b\^a]\  /; \ FreeQ[{a}, Complex]\ , \n\n\t\t
             (*******************) \n\t\t\t
            a_Times\ Log[b_] :> \n\t\t (*******************) \n\t\t
              Times@@Cases[a, _Complex] 
                Log[b\^\(a\/Times@@Cases[a, _Complex]\)]\n\t}\ ; \n\t\t\t\n\t
        Protect[#]\n]\)[Unprotect[LogSimplifyRules]]\)], "Input"],

Cell[BoxData[
    \({"LogSimplifyRules"}\)], "Output"]
}, Open  ]],

Cell["\<\
The effect of this function is that complex numbered terms stay before \
logarithms, while otherwise they are simplified correctly:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\ Log[x + \[ImaginaryI], y - \[ImaginaryI]] + b\ Log[z] // LogSimplify
      \)], "Input"],

Cell[BoxData[
    \(Log[\((\(-I\) + y)\)\^a]\/Log[I + x] + Log[z\^b]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\ \[ImaginaryI]\ Log[x, y - \[ImaginaryI]] + 
        b\ \[ImaginaryI]\ Log[z] // LogSimplify\)], "Input"],

Cell[BoxData[
    \(I\ Log[\((\(-I\) + y)\)\^\(a\/Log[x]\)\ z\^b]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ImaginaryI]\ a\^2\ Log[a, b] // LogSimplify\)], "Input"],

Cell[BoxData[
    \(I\ Log[b\^\(a\^2\/Log[a]\)]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Analytical Formulation"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell[TextData[{
  "In literature the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function not always is given analytically, while ",
  Cell[BoxData[
      \(TraditionalForm\`Tan[\ ]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Sin[\ ]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Cos[\ ]\)]],
  " usually have got this kind of alternative formulation, also the similar \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`Sinh[\ ]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Cosh[\ ]\)]],
  " etc. and even their area functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(demo[1] = {\(Exp[\[ImaginaryI]\ x] + Exp[\(-\[ImaginaryI]\)\ x]\)\/2, 
        \(Exp[\[ImaginaryI]\ x] - Exp[\(-\[ImaginaryI]\)\ x]\)\/\(2  
            \[ImaginaryI]\)}; \ndemo[1] // FullSimplify\)], "Input"],

Cell[BoxData[
    \({Cos[x], Sin[x]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To get a deep understanding of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function, also an explicit formulation by simpler functions is sensible, \
where this formulation is allowed to make use of complex numbered terms. It \
is valid for complex numbered arguments anyway."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Derivation out of Trigonometric Functions"
}], "Subsubsection"],

Cell[TextData[{
  "If the term ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[\[ImaginaryI]\ x] \[Rule] a\)]],
  " is handled to be a proper variable, a determining equation of the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " results:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(determine[1] = Last[demo[1]]\/First[demo[1]] == Tan[x]\), 
    \(determine[1] // FullSimplify\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(I\ \((\(-E\^\(\(-I\)\ x\)\) + E\^\(I\ x\))
              \)\)\/\(E\^\(\(-I\)\ x\) + E\^\(I\ x\)\)\)\) == Tan[x]\)], 
  "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This determining equation is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`Tan[x] \[Rule] y\)]],
  " and solved to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[1] = \(Solve[# == y, x]&\)/@\(List@@determine[1]\)\)], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \( : \ \) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \(Solve::"ifun" \( : \ \) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \({{{x \[Rule] \(-I\)\ Log[\(-\@\(\(I - y\)\/\(I + y\)\)\)]}, {
          x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}}, {{
          x \[Rule] ArcTan[y]}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now an analytical formulation of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function exists. The ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  "-periodic thus an explicit check is sensible to find out what results with \
",
  Cell[BoxData[
      \(TraditionalForm\`y \[Rule] 0\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[1] /. y \[Rule] 0\)], "Input"],

Cell[BoxData[
    \({{{x \[Rule] \[Pi]}, {x \[Rule] 0}}, {{x \[Rule] 0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
Thus the positive sign of the square root is to be used within the logarithm:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[1, 1] = Last/@result[1]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}, {
        x \[Rule] ArcTan[y]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The negative sign before the alternative ",
  Cell[BoxData[
      \(TraditionalForm\`result[1, 1]\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " now being found out, can be omitted by inversion of the fraction or the \
exchange ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] \(-\[ImaginaryI]\)\)]],
  " followed by canceling of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  "."
}], "Text"],

Cell["\<\
The identity both of the expressions is shown if two function values are \
identical and futhermore the differentiation is fitting to both:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[y] = 
      \(\(\[PartialD]\_y\((x /. result[1])\) // Simplify\) // Flatten\) // 
        Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell["This is fulfilled.", "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " check"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[1, 1]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}, {
        x \[Rule] ArcTan[y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking[1] = 
      \(\(\(#1 == #2&\)@@\((x /. result[1, 1])\) // PowerExpand\) // 
          LogSimplify\) // Simplify\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[\(-\(\(\(-I\) + y\)\/\(I + y\)\)\)] == 
      ArcTan[y]\)], "Output"]
}, Open  ]],

Cell["\<\
does not work, which means nothing to the content, but makes it very hard to \
recognize the connection.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Derivation by an Integral"
}], "Subsubsection"],

Cell["An independent derivation results by use of an integral of", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[y]\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell["\<\
The integral of this term results by complex valued taking apart to a sum of \
fractions:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(term[y] = 
      Simplify/@
        \((Apart[First[diff[y]] /. y \[Rule] \[ImaginaryI]\ x] /. 
            x \[Rule] \(-\[ImaginaryI]\)\ y)\)\)], "Input"],

Cell[BoxData[
    \(I\/\(2\ I - 2\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["An alternative form of this result is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(alternative[y] = 
      Plus@@Simplify[List@@term[y] /. y \[Rule] \[ImaginaryI]\ x] /. 
        x \[Rule] \(-\[ImaginaryI]\)\ y\)], "Input"],

Cell[BoxData[
    \(1\/\(2 - 2\ I\ y\) + 1\/\(2 + 2\ I\ y\)\)], "Output"]
}, Open  ]],

Cell["The taking apart to a sum of fractions yields by hand:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(byhand[y] = 
      \(\(1\/2\) 
            \((\[ImaginaryI]\/\(\[ImaginaryI] - y\) + 
                \[ImaginaryI]\/\(\[ImaginaryI] + y\))\) // Expand\) // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(I\/\(2\ I - 2\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["This result already occured by making use of the machine:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(term[y] == byhand[y]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A further trial checks, whether ",
  Cell[BoxData[
      \(TraditionalForm\`i\^2 \[Equal] \(-1\)\)]],
  " in this connection is also valid with exchanged sign:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(byhand[y] = 
      Simplify/@
        \((Apart[First[diff[y]] /. y \[Rule] \[ImaginaryI]\ x] /. 
            x \[Rule] \[ImaginaryI]\ y)\)\)], "Input"],

Cell[BoxData[
    \(1\/\(2 + 2\ I\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["The sums of fractions are all correct:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({term[y], alternative[y], byhand[y]} // Simplify\) // Union\)], 
  "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The integration over ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\)]],
  " now results totally unequivocal natural logarithms:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[1] = \(\[Integral]# \[DifferentialD]y&\)/@\(List@@term[y]\)\)], 
  "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[2] = 
      \(\[Integral]# \[DifferentialD]y&\)/@\(List@@alternative[y]\)\)], 
  "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[3] = \(\[Integral]# \[DifferentialD]y&\)/@\(List@@byhand[y]\)\)], 
  "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell["The sum of both terms results in each case:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[2] = \(Plus@@trial[#]&\)/@Range[3] // Union\)], "Input"],

Cell[BoxData[
    \({ArcTan[y]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "By this the secret of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function is not unveiled."
}], "Text"],

Cell[TextData[{
  "To stay at the formality of integration, here ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] z\)]],
  " is replaced. This is valid, because the correct Riemann leaf is taken \
into consideration by giving the lower integration limit explicitly:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[4] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((term[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(1\/2\ c\ Log[\(-c\)] - 1\/2\ c\ Log[c] - 1\/2\ c\ Log[\(-c\) + y] + 
      1\/2\ c\ Log[c + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[5] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((alternative[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(\(I\ \[Pi]\)\/\(2\ c\) - Log[\(-1\) + c\ y]\/\(2\ c\) + 
      Log[1 + c\ y]\/\(2\ c\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[6] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((byhand[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ c\ Log[c] + 1\/2\ c\ Log[c + y] + 
      Log[1 + c\ y]\/\(2\ c\)\)], "Output"]
}, Open  ]],

Cell["Meanwhile the formal integration by hand results:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trial[7] = 
      \(-\(\[ImaginaryI]\/2\)\) Log[\[ImaginaryI] - y] + 
        \(\[ImaginaryI]\/2\) Log[\[ImaginaryI] + y]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[I - y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell["\<\
Here the lower integration limit zero automatically has been taken into \
consideration:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(trial[#]&\)/@Range[4, 7] /. y \[Rule] 0 // Union\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Integration Techniques of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Subsubsection"],

Cell[TextData[{
  "This approach may be elegant, but leads to fallacies if the lower \
integration limit does not fit at the moment to get the integral. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program however leads to correct results for ",
  Cell[BoxData[
      \(TraditionalForm\`y > 0\)]],
  ", especially in the limit ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] 0\)]],
  ". These refinements often are overseen at calculation by hand."
}], "Text"],

Cell["\<\
The principle in handling computer algebra is, that the systematic ways to \
avoid analytical fallacies are studied efficiently. The consequence of \
calculation of the machine cannot be fooled as easy as a human:\
\>", "Text"],

Cell["Adventurous results not always prove bad implementation!", "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["\<\
The problem of the unique start on the Riemann leaf of the complex valued \
logarithmic result can be solved by explcitly given integration limits only. \
In the long run this problem of weakly understood integrals can be solved \
only by giving the connected integration limits to each integration result!\
\>", "Text"],

Cell["\<\
Thus an automatically generated integral should give the results and a \
warning which mentiones the connected integration limits explicitly. This \
warning should be switched off mainly if an integral is needed by a function \
which wants to give in the concrete integration limits.\
\>", "Text"],

Cell[TextData[{
  "Furthermore a possibility to get a literature cite to the respective \
calculation (by use of an option ",
  Cell[BoxData[
      \(TraditionalForm\`ShowLiterature \[Rule] True\)]],
  ") would not be objectionable in general."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Checking Calculation about the Integrals"
}], "Subsubsection"],

Cell["The differentiation results:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[4] = \(\[PartialD]\_y trial[4] // Together\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(c\^2\/\(c\^2 - y\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[5] = \[PartialD]\_y trial[5] // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/\(1 - c\^2\ y\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[6] = \[PartialD]\_y trial[6] // Together\)], "Input"],

Cell[BoxData[
    \(\(2\ c + y + c\^2\ y\)\/\(2\ \((c + y)\)\ \((1 + c\ y)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[7] = \[PartialD]\_y trial[7] // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/\(1 + y\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[Rule] \(-1\)\)]],
  " this is the result being searched for in each case:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({diff[4], diff[5], diff[6], diff[7]} /. c \[Rule] \[ImaginaryI] // 
        Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({diff[4], diff[5], diff[6], diff[7]} /. 
          c \[Rule] \(-\[ImaginaryI]\) // Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The substitution back to ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] \[ImaginaryI]\)]],
  " results formally:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[4] = trial[4] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/2 - 1\/2\ I\ Log[\(-I\) + y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[5] = trial[5] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/2 + 1\/2\ I\ Log[\(-1\) + I\ y] - 1\/2\ I\ Log[1 + I\ y]\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[6] = trial[6] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/4 - 1\/2\ I\ Log[1 + I\ y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(result[7] = trial[7]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[I - y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell["\<\
Here there are indeed differences when looking to each solution.\
\>", "Text"],

Cell[TextData[{
  "The didactically optimiced formulation of the result differs from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " formulation being optimized for calculation aspects, too and reads the \
following:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(didactical
       = {\[ImaginaryI]\ 
          Log[\@\(\(\[ImaginaryI] + y\)\/\(\[ImaginaryI] - y\)\)], 
        \(\[ImaginaryI]\/2\) 
          Log[\(\[ImaginaryI] + y\)\/\(\[ImaginaryI] - y\)], 
        \(\(-\[ImaginaryI]\)\/2\) 
          Log[\(\(-\[ImaginaryI]\) + y\)\/\(\(-\[ImaginaryI]\) - y\)]}\)], 
  "Input"],

Cell[BoxData[
    \({I\ Log[\@\(\(I + y\)\/\(I - y\)\)], 
      1\/2\ I\ Log[\(I + y\)\/\(I - y\)], 
      \(-\(1\/2\)\)\ I\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]}\)], "Output"]
}, Open  ]],

Cell["These formulations are correct:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[PartialD]\_y #&\)/@didactical // Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(didactical /. y \[Rule] 0 // Union\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In this formulation the possibility ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] \(\[PlusMinus]\@\(-1\)\)\)]],
  " still is enclosed! Now the resulted functions are identical formulations \
of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Intersection: Prolongation of the Root Nomenclature"
}], "Subsubsection"],

Cell[TextData[{
  "By ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " an identity of this kind can hardly be found only, because a separation \
of cases is not taken into account when calculating roots and furthermore, \
the theorems of simplifying combination of logarithmic terms are not \
implemented."
}], "Text"],

Cell["\<\
A correct implementation of a root always starts with the real valued root, \
possibly the positive one, and counts in a mathematical positive sense to the \
next one. By this the first mentioned root of a term is real valued, if real \
valued roots exist.\
\>", "Text"],

Cell["\<\
This kind of root symbol yet must be implemented. Forr this the following \
form is sensible:\
\>", "Text"],

Cell[BoxData[
    \(Radix[expr_, degree_, counter_] = 
      \(\@expr\%\(degree\  | \ counter\) = 
        expr\^\(1\/\(degree | counter\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "If the ",
  Cell[BoxData[
      \(TraditionalForm\`counter\)]],
  " is missing, a traditional root is discussed which also occurs at ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[LongDash]partially with reasoned surprisings because of the accuracy. \
For ",
  Cell[BoxData[
      \(TraditionalForm\`degree \[Equal] 0\)]],
  " all several roots are discussed together, namely the case where a \
separation of cases is not necessary to each root."
}], "Text"],

Cell[TextData[{
  "For the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function e.g. the following assumption is enough:"
}], "Text"],

Cell[BoxData[
    \(\[ImaginaryI]\^2 \[Equal] 
      \(-1\ \ \ \ \[DoubleLongLeftRightArrow]\ \ \ \ \[ImaginaryI]\) \[Equal] 
      \@\(-1\)\%\(2 | 0\) \[Equal] \(\[PlusMinus]\@\(-1\)\%\(2 | 1\)\) 
      \[Equal] \(\[MinusPlus]\@\(-1\)\%\(2 | 2\)\) \[Equal] 
      \(\[PlusMinus]\@\(-1\)\%2\) \[Equal] \(\[PlusMinus]\@\(-1\)\)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "There are no calculation rules availlable about the signs ",
  Cell[BoxData[
      \(TraditionalForm\`\[PlusMinus]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[MinusPlus]\)]],
  " at the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "If the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " root of a complex valued term os to be calculated, the counting starts at \
a further place, namely where the complex angular of the argument is reduced \
to the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " part (in mathematical positive sense). This Kind of root calculation is \
implemented at ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and due to the function ",
  Cell[BoxData[
      \(TraditionalForm\`Power[\ ]\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Problems on Checking"
}], "Subsubsection"],

Cell[TextData[{
  "The comparison with the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " results already found, now yields no problems with the Riemann leaf at \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking[4] = 
      \(\(\((x == result[4] /. result[1, 1])\) // FullSimplify\) // 
          LogSimplify\) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 1\/2\ \((\[Pi] - I\ Log[\(-I\) + y] + I\ Log[I + y])\)}\)],
   "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking[5] = 
      \(\(\((x == result[5] /. result[1, 1])\) // FullSimplify\) // 
          LogSimplify\) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 
        1\/2\ \((\[Pi] + I\ Log[\(-1\) + I\ y] - I\ Log[1 + I\ y])\)}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking[6] = 
      \(\(\((x == result[6] /. result[1, 1])\) // FullSimplify\) // 
          LogSimplify\) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 1\/4\ \((\[Pi] - 2\ I\ Log[1 + I\ y] + 2\ I\ Log[I + y])\)}
      \)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking[7] = 
      \(\((x == result[7] /. result[1, 1])\) // Simplify\) // LogSimplify\)], 
  "Input"],

Cell[BoxData[
    \({True, ArcTan[y] == \(-\(1\/2\)\)\ I\ Log[\(I - y\)\/\(I + y\)]}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
This checking yields clearness! This is a demonstration at an example that \
the known calculation rules are also valid with complex values and can be \
used.\
\>", "Text"],

Cell[TextData[{
  "Furthermore some interesting identities of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function are found out, which until now are not found in usual \
mathematical libraries? By correct handling of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " this kind of connections can be found out, checked and deepened."
}], "Text"],

Cell[TextData[{
  "The formulation of the analytical ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function being proper for teaching is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(didactical\)], "Input"],

Cell[BoxData[
    \({I\ Log[\@\(\(I + y\)\/\(I - y\)\)], 
      1\/2\ I\ Log[\(I + y\)\/\(I - y\)], 
      \(-\(1\/2\)\)\ I\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]}\)], "Output"]
}, Open  ]],

Cell["\<\
These three formulae can be summarized to one by use of an enlargened root \
nomenclature (see above).\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Further Connections"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Derivation of Trigonometric Connections"
}], "Subsubsection"],

Cell[TextData[{
  "The complex valued formulation of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function being found shows how corresponding trigonometric theorems can \
be based on elementary calculations (also automatized):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theorems[1] = \({Cos[#], Sin[#], Tan[#], Cot[#]}&\)/@didactical\)], 
  "Input"],

Cell[BoxData[
    \({{\(1 + \(I + y\)\/\(I - y\)\)\/\(2\ \@\(\(I + y\)\/\(I - y\)\)\), 
        \(I\ \((\(-1\) + \(I + y\)\/\(I - y\))\)\)\/\(2\ 
            \@\(\(I + y\)\/\(I - y\)\)\), 
        \(I\ \((\(-1\) + \(I + y\)\/\(I - y\))\)\)\/\(1 + 
            \(I + y\)\/\(I - y\)\), 
        \(-\(\(I\ \((1 + \(I + y\)\/\(I - y\))\)\)\/\(\(-1\) + 
                \(I + y\)\/\(I - y\)\)\)\)}, {
        Cosh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        I\ Sinh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        I\ Tanh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        \(-I\)\ Coth[1\/2\ Log[\(I + y\)\/\(I - y\)]]}, {
        Cosh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        \(-I\)\ Sinh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        \(-I\)\ Tanh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        I\ Coth[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]]}}\)], "Output"]
}, Open  ]],

Cell["\<\
The change to hyperbolic functions here is of more formal interest, but \
instructive:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theorems[1, 2] = 
      \(\(theorems[1] // LogSimplify\) // PowerExpand\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \({{I\/\(\@\(I - y\)\ \@\(I + y\)\), 
        \(I\ y\)\/\(\@\(I - y\)\ \@\(I + y\)\), y, 1\/y}, {
        I\/\(\@\(I - y\)\ \@\(I + y\)\), 
        \(I\ y\)\/\(\@\(I - y\)\ \@\(I + y\)\), y, 1\/y}, {
        \(-\(I\/\(\@\(\(-I\) - y\)\ \@\(\( - I\) + y\)\)\)\), 
        \(-\(\(I\ y\)\/\(\@\(\(-I\) - y\)\ \@\(\( - I\) + y\)\)\)\), y, 1\/y}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The remaining problems of the calculation reduce to the product of two \
square roots, which must be simplified with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by an own ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theorems[1, 3] = theorems[1, 2] /. TimesRule // Union\)], "Input"],

Cell[BoxData[
    \({{\(-\(I\/\@\(\(-1\) - y\^2\)\)\), 
        \(-\(\(I\ y\)\/\@\(\(-1\) - y\^2\)\)\), y, 1\/y}, {
        I\/\@\(\(-1\) - y\^2\), \(I\ y\)\/\@\(\(-1\) - y\^2\), y, 1\/y}}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "These results fit to the literature (e.g. ",
  ButtonBox["[GKHKR1974]",
    ButtonData:>"[GKHKR1974]",
    ButtonStyle->"Hyperlink"],
  ", table, page 278), where also the alternating sign before the square root \
is mentioned."
}], "Text"],

Cell[TextData[{
  "It is important to mention that the other arcus functions can be described \
from the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " via the given algebraic connections. The elementary function to do \
already at each BASIC is called ",
  Cell[BoxData[
      \(TraditionalForm\`ATN\)]],
  " and shows also the advantages of FORTRAN, the first programming language \
which allows calculations withh complex numbers already by default."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Calculation of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " Roots"
}], "Subsubsection"],

Cell[TextData[{
  "According to F. Vieta (see ",
  ButtonBox["[GKHKR1974]",
    ButtonData:>"[GKHKR1974]",
    ButtonStyle->"Hyperlink"],
  ", page 110-111) the latest since about 1600 the ",
  StyleBox["casus irreducibilis",
    FontSlant->"Italic"],
  " of cubic equations has been an occasion to divide the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " by a real number, where thus a separation into ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " parts of the corresponding angular takes place. Also Johann Faulhaber in \
1604 has shown by his teaching volume ",
  StyleBox["Arithmetisch-Cubiccosischer Lustgarten",
    FontSlant->"Italic"],
  " (86 pages, city library of Ulm 43210, microfilm 23; cited due to ",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", section 2.3, page 150) a contentional connection of this kind."
}], "Text"],

Cell[TextData[{
  "This means that the trigonometric functions are to be applied to the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " part of the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function. According to the completed logarithmic description this riddle \
formally is solved completely:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nthroot = didactical\/n /. y \[Rule] z // LogSimplify\)], "Input"],

Cell[BoxData[
    \({I\ Log[\((\(I + z\)\/\(I - z\))\)\^\(1\/\(2\ n\)\)], 
      1\/2\ I\ Log[\((\(I + z\)\/\(I - z\))\)\^\(1\/n\)], 
      \(-\(1\/2\)\)\ I\ Log[\((\(\(-I\) + z\)\/\(\(-I\) - z\))\)\^\(1\/n\)]}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The corresponding roots are given to the argument of the logarithm \
function. Formally this is an inversion into the ",
  StyleBox["casus irreducibilis",
    FontSlant->"Italic"],
  " and some more difficulties of calculation. Mainly important is the \
didactical preparation of this connection."
}], "Text"],

Cell[TextData[{
  "When calculation the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " root of a complex number ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[ImaginaryI]\ y\)]],
  " the absolute value ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x\^2 + y\^2\)\)]],
  " and of course also the real and imaginary part of the root are of \
interest."
}], "Text"],

Cell[TextData[{
  "The real part of the root ist the absolute value mutiplied by the cosinus \
of the corresponding phase angular, the imaginary part is the product of \
absolute value and sinus of the phase angular. The phase angular ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi] \[Equal] ArcTan[z \[Equal] y\/x]\)]],
  " is additional to the now known formula all that is important to determine \
real and imaginary part of an ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " root:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trigroots[1] = 
      Simplify[\(\(\({Cos[#], \[ImaginaryI]\ Sin[#]}&\)/@nthroot /. 
                    z \[Rule] y\/x // LogSimplify\) // 
                MapAll[Together, #]&\) // PowerExpand] /. TimesRule // Union; 
    \nMatrixForm/@trigroots[1] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      InterpretationBox[
        RowBox[{"(", GridBox[{
             
               {\(1\/2\ 
                  \((\((x - I\ y)\)\^\(1\/n\) + \((x + I\ y)\)\^\(1\/n\))\)\ 
                  \((x\^2 + y\^2)\)\^\(-\(1\/\(2\ n\)\)\)\)},
             
               {\(1\/2\ 
                  \((\(-\((x - I\ y)\)\^\(1\/n\)\) + \((x + I\ y)\)\^\(1\/n\))
                    \)\ \((x\^2 + y\^2)\)\^\(-\(1\/\(2\ n\)\)\)\)}
              }], ")"}],
        MatrixForm[ {
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, -1], y]], 
                Power[ n, -1]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]], 
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Times[ -1, 
                Power[ 
                  Plus[ x, 
                    Times[ 
                      Complex[ 0, -1], y]], 
                  Power[ n, -1]]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]]}]],
      TableForm[ {
        MatrixForm[ {
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, -1], y]], 
                Power[ n, -1]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]], 
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Times[ -1, 
                Power[ 
                  Plus[ x, 
                    Times[ 
                      Complex[ 0, -1], y]], 
                  Power[ n, -1]]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]]}]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " root of a complex number consists of the real part of this root plus ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\)]],
  " times of the imaginary part of the same."
}], "Text"],

Cell["\<\
The real part consists of the arithmetical means of root and complex \
conjugated root, for the imaginary part a difference is needed. This result \
completes clearly that power terms of complex numbers also are complex \
numbers.\
\>", "Text"],

Cell[TextData[{
  "If also complex valued root orders ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " are discussed, a product of real power and imaginary power is build, \
where the basic insight"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((a + \[ImaginaryI]\ b)\)\^\(x + \[ImaginaryI]\ y\) // ComplexExpand
      \)], "Input"],

Cell[BoxData[
    \(E\^\(\(-y\)\ Arg[a + I\ b]\)\ Abs[a + I\ b]\^x\ 
        Cos[x\ Arg[a + I\ b] + y\ Log[Abs[a + I\ b]]] + 
      I\ E\^\(\(-y\)\ Arg[a + I\ b]\)\ Abs[a + I\ b]\^x\ 
        Sin[x\ Arg[a + I\ b] + y\ Log[Abs[a + I\ b]]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "stays valid. If ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y} \[Element] \[DoubleStruckCapitalR]\)]],
  " is assumed, there is a simplification ",
  Cell[BoxData[
      \(TraditionalForm\`Arg[a + \[ImaginaryI]\ b] \[Rule] ArcTan[b\/a]\)]],
  ", and the logarithm of a complex number must be discussed due to its \
ambiguousity related to the Riemann leafs. The result of the operation is a \
complex number. If ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y}\)]],
  " are complex valued, there is always a possibility to reduce them to a \
fitting alternative quadrupel."
}], "Text"],

Cell["The following sentence results:", "Text"],

Cell["\<\
If the complex conjugated function of a complex number
is the same as the function of the complex conjugated number,
there is a possibility to separate real and imaginary part
of the function by calculation methods,
also if the concrete shape of the function stays unknown.\
\>", "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["\<\
By this all complex valued power terms of complex numbers can be understood. \
Analytical functions of complex numbers which do not have these properties, \
are not so easy to be formulated.\
\>", "Text"],

Cell[TextData[{
  "With ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the real part function ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\ ]\)]],
  " and the imaginary part function ",
  Cell[BoxData[
      \(TraditionalForm\`Im[\ ]\)]],
  " do not give for ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots a change into a sum or difference of complex conjugated roots, \
because the numerics of both terms results a little different absolute values \
and thus rejects a clear separation into real and imaginary part. The \
asymmetry of the numerics is caused by the binary system and contentional \
sensible, because the effective calculation accuracy stays always measurable. \
A replacing rule to recognize automatically ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\ ]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Im[\ ]\)]],
  " of power terms until now unfortunately does not exist. This should be \
added to improve the corresponding numerics for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " checks."
}], "Text"],

Cell["\<\
The insight of Gau\[SZ] that the separation of an angular into seven parts is \
identical to the solution of an equation of degree seven, is also confirmed \
by this.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Nature and Meaning of Prime Numbers"
}], "Subsubsection"],

Cell[TextData[{
  "Now is to be shown that for the calculation of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots only the roots of prime numbered order are singular, because all \
other roots of natural order of a complex number can be calculated by \
iteration."
}], "Text"],

Cell["\<\
Quadratic equations have got an unequivocal solution containing just one root \
term. For this there is a possibility to separate real and imaginary part of \
square roots clearly. The geometrical construction to half an angular also \
exists.\
\>", "Text"],

Cell["The derivation of this connection may be this one:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(problem = 
      MapIndexed[
        \((\@\(a + b\) + \(\((\(-1\))\)\^First[#2]\) \@\(a - b\) == #1)\)&, {
          A, B}]; \nproblem // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(\(-\@\(a - b\)\) + \@\(a + b\) == A\)},
            {\(\@\(a - b\) + \@\(a + b\) == B\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ -1, 
              Power[ 
                Plus[ a, 
                  Times[ -1, b]], 
                Rational[ 1, 2]]], 
            Power[ 
              Plus[ a, b], 
              Rational[ 1, 2]]], A], 
        Equal[ 
          Plus[ 
            Power[ 
              Plus[ a, 
                Times[ -1, b]], 
              Rational[ 1, 2]], 
            Power[ 
              Plus[ a, b], 
              Rational[ 1, 2]]], B]}]]], "Output"]
}, Open  ]],

Cell["Squaring of both equations in the given position yields:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(square = ExpandAll[Map[#\^2&, problem, {2}]] /. TimesRule; \n
    square // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(2\ a - 2\ \@\(a\^2 - b\^2\) == A\^2\)},
            {\(2\ a + 2\ \@\(a\^2 - b\^2\) == B\^2\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ 2, a], 
            Times[ -2, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]]], 
          Power[ A, 2]], 
        Equal[ 
          Plus[ 
            Times[ 2, a], 
            Times[ 2, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]]], 
          Power[ B, 2]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "By substraction of ",
  Cell[BoxData[
      \(TraditionalForm\`2  a\)]],
  " in both equations and squaring afterward results:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(determiningequation = 
      Map[#\^2&, Map[# - 2  a&, square, {2}], {2}] // Simplify; \n
    determiningequation // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(4\ a\ A\^2 - A\^4 - 4\ b\^2 == 0\)},
            {\(\(-4\)\ b\^2 + 4\ a\ B\^2 - B\^4 == 0\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ 4, a, 
              Power[ A, 2]], 
            Times[ -1, 
              Power[ A, 4]], 
            Times[ -4, 
              Power[ b, 2]]], 0], 
        Equal[ 
          Plus[ 
            Times[ -4, 
              Power[ b, 2]], 
            Times[ 4, a, 
              Power[ B, 2]], 
            Times[ -1, 
              Power[ B, 4]]], 0]}]]], "Output"]
}, Open  ]],

Cell["\<\
These biquadratic equations can be solved formally where a checking \
calculation is indispensable:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(formalsolution = 
      MapThread[Solve[#1, #2]&, {determiningequation, {A, B}}]; \n
    Transpose[formalsolution] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(A \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{A -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}}]]], "Output"]
}, Open  ]],

Cell["\<\
All four solutions are pairwise identical. This alone already shows the \
necessity of checking:\
\>", "Text"],

Cell["\<\
Alle vier L\[ODoubleDot]sungen sind paarweise identisch. Allein dies zeigt \
schon die Notwendigkeit der Probe:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(checking = 
      ExpandAll[
            Map[#\^2&, 
              \((problem /. Flatten/@Transpose[formalsolution])\), {3}]] /. 
          TimesRule // Simplify; \nchecking // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"True", \(4\ \@\(a\^2 - b\^2\) == 0\)},
          {"True", \(4\ \@\(a\^2 - b\^2\) == 0\)},
          {\(\(-4\)\ \@\(a\^2 - b\^2\) == 0\), "True"},
          {\(\(-4\)\ \@\(a\^2 - b\^2\) == 0\), "True"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The solutions being confirmed independently of the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " are concluded:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(squaresolution = 
      \({Take[First[#], 2], Take[Last[#], \(-2\)]}&\)@formalsolution; \n
    \(squaresolution // Transpose\) // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(A \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{A -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}}]]], "Output"]
}, Open  ]],

Cell["\<\
The enclosing square root has got an alternating sign being confirmed by \
squaring and therefore not being relevant. The positive sign before the root \
in case of doubt is the correct formulation for a teaching book.\
\>", "Text"],

Cell[TextData[{
  "Now the following root theorems are proven for all ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y} \[Element] \[DoubleStruckCapitalC]\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\@\(a + b\) \[PlusMinus] \@\(a - b\) == 
      \@\(2  a \[PlusMinus] 2 \@\( a\^2 - b\^2\)\) == 
      \@\(2  a \((1 \[PlusMinus] \@\(1 - \((b\/a)\)\^2\))\)\)\), 
    \(\@\(x \[PlusMinus] \@y\) == 
      \@\(x\/2 + \@\(x\^2\/4 - y\/4\)\) \[PlusMinus] 
        \@\(x\/2 - \@\(x\^2\/4 - y\/4\)\)\), 
    \(\@\(x \[PlusMinus] \[ImaginaryI]\ y\) == 
      \@\(\(\@\(x\^2 + y\^2\) + x\)\/2\) \[PlusMinus] 
        \[ImaginaryI]\ \@\(\(\@\(x\^2 + y\^2\) - x\)\/2\)\), 
    \(\@\(x + \[ImaginaryI]\ y\) \[PlusMinus] \@\(x - \[ImaginaryI]\ y\) == 
      \@\(2  x \[PlusMinus] 2 \@\( x\^2 + y\^2\)\) == 
      \@\(2  x \((1 \[PlusMinus] \@\(1 + \((y\/x)\)\^2\))\)\)\)}], 
  "NumberedEquation",
  CellTags->"squareroots"],

Cell[TextData[
"The iterated use of square roots indicates that a formulation without this \
iteration exists\[LongDash]however with complex numbers then. The iteration \
of roots deepenes at addition of iterated roots respectively."], "Text"],

Cell[TextData[{
  "By iterated use of this connection (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "squareroots"],
  ") e.g. the fourth root of a complex number results the following:"
}], "Text"],

Cell[BoxData[
    \(\(\@\(x \[PlusMinus] \[ImaginaryI]\ y\)\%4 = 
      \(\@\(\@\(\(\@\(x\^2 + y\^2\) + x\)\/2\) \[PlusMinus] 
            \[ImaginaryI]\ \@\(\(\@\(x\^2 + y\^2\) - x\)\/2\)\) = \n\t
        \@\(\(\@\(x\^2 + y\^2\)\%4 + \@\(\(x + \@\(x\^2 + y\^2\)\)\/2\)\)\/2
                \) \[PlusMinus] 
          \[ImaginaryI] 
            \@\(\(\@\( x\^2 + y\^2\)\%4 - 
                    \@\(\(x + \@\(x\^2 + y\^2\)\)\/2\)\)\/2\)\)\t\)\)], 
  "NumberedEquation"],

Cell["\<\
A fourfold sum of fourth roots beneath the square root also is possible.\
\>", "Text"],

Cell[TextData[{
  "The root of a complex number usually occurs first at at equations of \
degree four with real numbered coefficients, thus in analogy to this the \
fourth root of a complex nnumber belongs to an equation of degree eight with \
real numbered coefficients. The character of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^2 \[Equal] \(-1\)\)]],
  " emphasizes this connection."
}], "Text"],

Cell[TextData[{
  "If the terms ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " each are complex numbers, another separation of real and imaginary part \
results, whereof a general theorem of ",
  Cell[BoxData[
      \(TraditionalForm\`2  n\)]],
  "-ordered roots of complex numbers for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Element] \[DoubleStruckCapitalN]\)]],
  " is derivable."
}], "Text"],

Cell["\<\
By this is shown that only roots of prime numbered order are also \
\"primary\". The infinity of prime numbers leads to an inexhaustable treasure \
of problems of analytical mathematics.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Outlook to Music Theory"
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " owns a very nice counting of prime numbers:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Prime\)\)], "Input"],

Cell[BoxData[
    \("Prime[n] gives the nth prime number."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Depending on the definition ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " is positive and only by number one and itself divisable. Therefore it \
seems to be sensible to enlarge the definition in the sense of Wolframs \
counting:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Function[\n\t (************) \n\t\t
        Prime[0] := \n\t (************) \n\t1\ ; \n\n\tProtect[#]\n]\)[
      Unprotect[Prime]]\t\)\)], "Input"],

Cell[BoxData[
    \({"Prime"}\)], "Output"]
}, Open  ]],

Cell["\<\
From this results the insight that the first fourteen prime mumbers are the \
following:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Prime[7  # + Range[0, 6]]&\)/@Range[0, 2] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "5", "7", "11", "13"},
            {"17", "19", "23", "29", "31", "37", "41"},
            {"43", "47", "53", "59", "61", "67", "71"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The counting of Wolfram (",
  ButtonBox["[Wol1997]",
    ButtonData:>"[Wol1997]",
    ButtonStyle->"Hyperlink"],
  ", section 3.2.4, page 781), which correlates to Greek philosophy, is also \
sensible:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prime[13]\)], "Input"],

Cell[BoxData[
    \(41\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For a rhythm of seven this is the only possibility to conclude from the \
\"week\"-end of the one to the end of the next \"week\". The list of seven \
numbers in this connection of prime numbers are also sensible: an algorithm \
to calculate the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " prime number needs e.g. a sieve of ",
  Cell[BoxData[
      \(TraditionalForm\`14\)]],
  " canceled fractions (",
  ButtonBox["[Oli1995]",
    ButtonData:>"[Oli1995]",
    ButtonStyle->"Hyperlink"],
  ", page 30-38) in two rows."
}], "Text"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`41\^th\)]],
  " root of number two in music theory plays a special role of musical \
harmony, because the corresponding equally disposed intervals"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervals[41] = 
      2\^\({{0, 3, 6, 7, 8, 9, 11, 13, 17, 20}, 
                Reverse[{21, 24, 28, 30, 32, 33, 34, 35, 38, 41}]}\/41\) // 
        N; \n\(intervals[41] // N[#, 5]&\) // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.05202627094241507`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.10675927475300395`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.12562923754815646`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.14482092838662707`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.16433983264933482`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.20438169218741708`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.24580059858957459`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.33296060817114137`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.40230957792741968`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["2.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.90109320959103396`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.80707769577656698`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.77678398293597901`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.74699811158987294`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.71771156832211957`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.66060312355593131`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.60539335288832791`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.50041943305740899`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.42621859786193239`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "enable extreme pure and harmonic sounds\[LongDash]also among others \
harmonic sounds of four voices ",
  ButtonBox["[SRGT1993]",
    ButtonData:>"[SRGT1993]",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervalconnection[41] = 
      \({#, Rationalize[#, 1\/100], 
            1200 \( Log[#/Rationalize[#, 1\/100]]\/Log[2]\) "\<Cent\>" // N}&
          \)/@intervals[41]; \n
    MatrixForm/@\(Transpose/@intervalconnection[41]\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.`", "1", \(0.`\ "Cent"\)},
               
                 {"1.05202627094241507`", \(20\/19\), 
                  \(\(-0.995819683751693496`\)\ "Cent"\)},
               
                 {"1.10675927475300395`", \(10\/9\), 
                  \(\(-6.79395603649854074`\)\ "Cent"\)},
               
                 {"1.12562923754815646`", \(9\/8\), 
                  \(0.968047049713360685`\ "Cent"\)},
               
                 {"1.14482092838662707`", \(8\/7\), 
                  \(2.97224793253998029`\ "Cent"\)},
               
                 {"1.16433983264933482`", \(7\/6\), 
                  \(\(-3.45627145739527597`\)\ "Cent"\)},
               
                 {"1.20438169218741708`", \(6\/5\), 
                  \(6.30993251164316593`\ "Cent"\)},
               
                 {"1.24580059858957459`", \(5\/4\), 
                  \(\(-5.82590898678522606`\)\ "Cent"\)},
               
                 {"1.33296060817114137`", \(4\/3\), 
                  \(\(-0.484023524855477482`\)\ "Cent"\)},
               
                 {"1.40230957792741968`", \(7\/5\), 
                  \(2.85366105424768399`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2.`", "2", \(0.`\ "Cent"\)},
               
                 {"1.90109320959103396`", \(19\/10\), 
                  \(0.995819683754090156`\ "Cent"\)},
               
                 {"1.80707769577656698`", \(9\/5\), 
                  \(6.7939560365012781`\ "Cent"\)},
               
                 {"1.77678398293597901`", \(16\/9\), 
                  \(\(-0.968047049710899898`\)\ "Cent"\)},
               
                 {"1.74699811158987294`", \(7\/4\), 
                  \(\(-2.97224793253778898`\)\ "Cent"\)},
               
                 {"1.71771156832211957`", \(12\/7\), 
                  \(3.45627145739807728`\ "Cent"\)},
               
                 {"1.66060312355593131`", \(5\/3\), 
                  \(\(-6.30993251164077761`\)\ "Cent"\)},
               
                 {"1.60539335288832791`", \(8\/5\), 
                  \(5.82590898678800606`\ "Cent"\)},
               
                 {"1.50041943305740899`", \(3\/2\), 
                  \(0.484023524857968023`\ "Cent"\)},
               
                 {"1.42621859786193239`", \(10\/7\), 
                  \(\(-2.85366105424528004`\)\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The declaration of the deviation of the intervals to the pure frequency \
relations is given in hundredths of half tunes (unit ",
  Cell[BoxData[
      \(TraditionalForm\`Cent\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "For comparisons to the ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-separated octave being spread within Europe is mentioned:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervalconnection[12] = 
      \({#, Rationalize[#, 1\/60], 
            1200 \( Log[#/Rationalize[#, 1\/60]]\/Log[2]\) "\<Cent\>" // N}&
          \)/@N[2\^\({Range[0, 6], Range[12, 6, \(-1\)]}\/12\)]; \n
    MatrixForm/@\(Transpose/@intervalconnection[12]\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.`", "1", \(0.`\ "Cent"\)},
               
                 {"1.0594630943592953`", \(18\/17\), 
                  \(1.04540776963254966`\ "Cent"\)},
               
                 {"1.12246204830937301`", \(9\/8\), 
                  \(\(-3.91000173077486579`\)\ "Cent"\)},
               
                 {"1.18920711500272101`", \(6\/5\), 
                  \(\(-15.6412870005527215`\)\ "Cent"\)},
               
                 {"1.25992104989487296`", \(5\/4\), 
                  \(13.6862861351648357`\ "Cent"\)},
               
                 {"1.33483985417003392`", \(4\/3\), 
                  \(1.95500086538684563`\ "Cent"\)},
               
                 {"1.4142135623730951`", \(7\/5\), 
                  \(17.4878073957100044`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2.`", "2", \(0.`\ "Cent"\)},
               
                 {"1.88774862536338616`", \(17\/9\), 
                  \(\(-1.04540776963330173`\)\ "Cent"\)},
               
                 {"1.78179743628067903`", \(16\/9\), 
                  \(3.91000173077513544`\ "Cent"\)},
               
                 {"1.68179283050742949`", \(5\/3\), 
                  \(15.6412870005527437`\ "Cent"\)},
               
                 {"1.58740105196819918`", \(8\/5\), 
                  \(\(-13.6862861351655018`\)\ "Cent"\)},
               
                 {"1.49830707687668107`", \(3\/2\), 
                  \(\(-1.95500086538796971`\)\ "Cent"\)},
               
                 {"1.4142135623730951`", \(7\/5\), 
                  \(17.4878073957100044`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Intervals (and deviations) are added by multiplication of the connected \
frequency relations.\
\>", "Text"],

Cell["\<\
The purely disposed triad types (moll and Dur) give the following interval \
sequences:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(triads = \(Times@@#&\)/@{{6\/5, 5\/4, 4\/3}, {4\/3, 5\/4, 6\/5}}\)], 
  "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Two of the purely disposed \"quadrad\" types (moll and Dur) give the \
following interval sequences:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(quadrads = 
      \(Times@@#&\)/@{{8\/7, 7\/6, 6\/5, 5\/4}, {5\/4, 6\/5, 7\/6, 8\/7}}\)], 
  "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Two of the purely disposed \"pentad\" types (moll and Dur) give the following \
interval sequences:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pentads = 
      \(Times@@#&
          \)/@{{10\/9, 9\/8, 8\/7, 7\/6, 6\/5}, {6\/5, 7\/6, 8\/7, 9\/8, 
            10\/9}}\)], "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The last mentioned interval sequences cannot satisfactory be build up \
within the equally disposed ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  "-separation of the octave. A pentad (sept-non-accord) also experimentally \
in all its inversions (1994, musical workshop of the university of Ulm) gave \
an extremely dissonant impression. The pentad in extremely pure disposition \
plays a role in styling marked electronic organ records."
}], "Text"],

Cell[TextData[{
  "Vivid pure (",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  ")-sounds are constructed by halving each largest interval of an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-sound asymmetrically."
}], "Text"],

Cell["The interval sequence", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times@@{4\/3, 9\/8, 4\/3}\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "sounds as a strange triad and has been used because of its consonance also \
already in old musicals of the ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-separated octave being a ",
  StyleBox["suspension",
    FontSlant->"Italic"],
  " before the actual final accord. This sound is an indefferent \
interpolation between ",
  StyleBox["Dur",
    FontSlant->"Italic"],
  " and ",
  StyleBox["moll",
    FontSlant->"Italic"],
  " and because of this it is not used as final accord, but for modulation."
}], "Text"],

Cell[TextData[{
  "Important for music is that due to Friedrich Smend (e.g. ",
  ButtonBox["[Sme1950]",
    ButtonData:>"[Sme1950]",
    ButtonStyle->"Hyperlink"],
  ", page 25-29) within the compositions of J.S.Bach are conspicious many \
sequences of ",
  Cell[BoxData[
      \(TraditionalForm\`14\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  " notes. A connection to the names BACH and J.S.BACH exists. The reflection \
for Bach has been an essential property of  the barock composition."
}], "Text"],

Cell[TextData[{
  "The technical possibilities to dispose and present the compositions of \
Bach in the sense of a ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  "-separated octave of seventh tones are meanwhile available by electronics. \
This suggestion should carefully be checked before hasty fallacies. The value \
of Bach's music mainly turns out by the fact that he took the possibility of \
a further refinement of the disposition intoo account: his own ",
  StyleBox["wohltemperierte",
    FontSlant->"Italic"],
  " (",
  StyleBox["well disposed",
    FontSlant->"Italic"],
  ") tune deviates from the equal disposed ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-separated octave a little bit (",
  ButtonBox["[Bill1989]",
    ButtonData:>"[Bill1989]",
    ButtonStyle->"Hyperlink"],
  ", page 30-31)."
}], "Text"],

Cell[TextData[{
  "By the now elaborated study about the ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " function a part of the ",
  StyleBox["non-understood rest problems of the studies",
    FontSlant->"Italic"],
  " has been answered yet elegantly."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Protocol"
}], "Section"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version has been:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "L4526-3546"}\)], 
  "Output"]
}, Open  ]],

Cell["The calculation time was (in seconds):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[]\)], "Input"],

Cell[BoxData[
    \(12.3300000000000009`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literature", "Subtitle"],

Cell[TextData[{
  "[Bill1989]\nBilleter B. ",
  StyleBox[
  "Anweisung zum Stimmen von Tasteninstrumenten in verschiedenen \
Temperaturen",
    FontSlant->"Italic"],
  ", Merseburger Kassel, 3rd improved edition, (1989)"
}], "Text",
  CellTags->"[Bill1989]"],

Cell[TextData[{
  "[GKHKR1974]\nGellert W., K\[UDoubleDot]stner H., Hellwich M., K\
\[ADoubleDot]stner H., Reichardt H. ",
  StyleBox["Kleine Enzyklop\[ADoubleDot]die Mathematik",
    FontSlant->"Italic"],
  ", VEB Bibliographisches Institut Leipzig, 9th shortened edition, (1974)"
}], "Text",
  CellTags->"[GKHKR1974]"],

Cell[TextData[{
  "[Haw1995]\nHawlitschek K. ",
  StyleBox[
  "Johann Faulhaber 1580 - 1635 Eine Bl\[UDoubleDot]tezeit der mathematischen \
Wissenschaften in Ulm",
    FontSlant->"Italic"],
  ", publications of the city library of Ulm, volume ",
  StyleBox["18",
    FontWeight->"Bold"],
  ", (1995)"
}], "Text",
  CellTags->"[Haw1995]"],

Cell[TextData[{
  "[Oli1995]\nOlivastro D. ",
  StyleBox["Das chinesische Dreieck",
    FontSlant->"Italic"],
  ", Droemersche Verlagsanstalt Th. Knaur Nachf. M\[UDoubleDot]nchen, German \
edition, (1995)"
}], "Text",
  CellTags->"[Oli1995]"],

Cell[TextData[{
  "[Sme1950]\nSmend F. ",
  StyleBox["Johann Sebastian Bach bei seinem Namen gerufen",
    FontSlant->"Italic"],
  ", B\[ADoubleDot]renreiter Kassel and Basel, (1950)"
}], "Text",
  CellTags->"[Sme1950]"],

Cell[TextData[{
  "[SRGT1993]\nS\[UDoubleDot]dland N., Rydyger K., Gr\[ADoubleDot]ber T., Tr\
\[UDoubleDot]stedt W.-D.  ",
  StyleBox["Wieviele T\[ODoubleDot]ne hat die Tonleiter?",
    FontSlant->"Italic"],
  ", journal of the musical workshop of the university of Ulm, (1993)"
}], "Text",
  CellTags->"[SRGT1993]"],

Cell[TextData[{
  "[Wol1997]\nWolfram S., ",
  StyleBox["Das Mathematica Buch",
    FontSlant->"Italic"],
  ", 3rd edition version 3, Addison-Wesley Bonn etc. 1997, also online help \
of ",
  StyleBox["Mathematica 3.0",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"[Wol1997]"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{784, 537},
WindowMargins->{{-4, Automatic}, {-4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], 
          "   \[Copyright]  Norbert S\[UDoubleDot]dland"}], "Header"]}, {
    Cell[ 
        TextData[ {
          ValueBox[ "FileName"], 
          "   \[Copyright]  Norbert S\[UDoubleDot]dland"}], "Header"], 
      Inherited, Inherited}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Open  ]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "squareroots"->{
    Cell[56802, 2057, 731, 14, 330, "NumberedEquation",
      CellTags->"squareroots"]},
  "[Bill1989]"->{
    Cell[75987, 2683, 258, 8, 93, "Text",
      CellTags->"[Bill1989]"]},
  "[GKHKR1974]"->{
    Cell[76248, 2693, 320, 7, 93, "Text",
      CellTags->"[GKHKR1974]"]},
  "[Haw1995]"->{
    Cell[76571, 2702, 337, 11, 93, "Text",
      CellTags->"[Haw1995]"]},
  "[Oli1995]"->{
    Cell[76911, 2715, 242, 7, 93, "Text",
      CellTags->"[Oli1995]"]},
  "[Sme1950]"->{
    Cell[77156, 2724, 220, 6, 69, "Text",
      CellTags->"[Sme1950]"]},
  "[SRGT1993]"->{
    Cell[77379, 2732, 316, 7, 93, "Text",
      CellTags->"[SRGT1993]"]},
  "[Wol1997]"->{
    Cell[77698, 2741, 281, 9, 93, "Text",
      CellTags->"[Wol1997]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"squareroots", 119221, 4221},
  {"[Bill1989]", 119328, 4224},
  {"[GKHKR1974]", 119421, 4227},
  {"[Haw1995]", 119513, 4230},
  {"[Oli1995]", 119604, 4233},
  {"[Sme1950]", 119694, 4236},
  {"[SRGT1993]", 119785, 4239},
  {"[Wol1997]", 119876, 4242}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 262, 3, 154, "Title",
  CounterAssignments->{{"Title", 20}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1996, 56, 231, 5, 120, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2252, 65, 99, 5, 76, "Section"],
Cell[2354, 72, 150, 5, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2541, 82, 98, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[2664, 91, 141, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[2830, 102, 232, 11, 61, "Subsubsection"],
Cell[3065, 115, 408, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[3498, 128, 1156, 20, 591, "Input"],
Cell[4657, 150, 47, 1, 41, "Output"]
}, Open  ]],
Cell[4719, 154, 225, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4981, 165, 242, 11, 61, "Subsubsection"],
Cell[5226, 178, 85, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[5336, 184, 417, 8, 366, "Input"],
Cell[5756, 194, 49, 1, 41, "Output"]
}, Open  ]],
Cell[5820, 198, 72, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5917, 202, 1038, 18, 795, "Input"],
Cell[6958, 222, 54, 1, 41, "Output"]
}, Open  ]],
Cell[7027, 226, 155, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[7207, 233, 111, 2, 41, "Input"],
Cell[7321, 237, 82, 1, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7440, 243, 127, 2, 41, "Input"],
Cell[7570, 247, 79, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7686, 253, 78, 1, 43, "Input"],
Cell[7767, 256, 61, 1, 63, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7889, 264, 152, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[8066, 275, 181, 9, 61, "Subsubsection"],
Cell[8250, 286, 595, 21, 93, "Text"],

Cell[CellGroupData[{
Cell[8870, 311, 229, 3, 95, "Input"],
Cell[9102, 316, 50, 1, 41, "Output"]
}, Open  ]],
Cell[9167, 320, 331, 7, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9535, 332, 212, 9, 61, "Subsubsection"],
Cell[9750, 343, 278, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[10053, 356, 128, 2, 97, "Input"],
Cell[10184, 360, 155, 3, 64, "Output"],
Cell[10342, 365, 38, 1, 41, "Output"]
}, Open  ]],
Cell[10395, 369, 212, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[10632, 381, 90, 1, 41, "Input"],
Cell[10725, 384, 154, 3, 84, "Message"],
Cell[10882, 389, 154, 3, 84, "Message"],
Cell[11039, 394, 194, 3, 74, "Output"]
}, Open  ]],
Cell[11248, 400, 430, 15, 69, "Text"],

Cell[CellGroupData[{
Cell[11703, 419, 57, 1, 41, "Input"],
Cell[11763, 422, 87, 1, 41, "Output"]
}, Open  ]],
Cell[11865, 426, 103, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[11993, 433, 63, 1, 41, "Input"],
Cell[12059, 436, 119, 2, 74, "Output"]
}, Open  ]],
Cell[12193, 441, 468, 15, 69, "Text"],
Cell[12664, 458, 163, 3, 69, "Text"],

Cell[CellGroupData[{
Cell[12852, 465, 133, 3, 44, "Input"],
Cell[12988, 470, 51, 1, 63, "Output"]
}, Open  ]],
Cell[13054, 474, 34, 0, 45, "Text"],
Cell[13091, 476, 100, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[13216, 485, 45, 1, 41, "Input"],
Cell[13264, 488, 119, 2, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13420, 495, 153, 3, 66, "Input"],
Cell[13576, 500, 111, 2, 63, "Output"]
}, Open  ]],
Cell[13702, 505, 128, 3, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13867, 513, 196, 9, 61, "Subsubsection"],
Cell[14066, 524, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[14165, 528, 40, 1, 41, "Input"],
Cell[14208, 531, 51, 1, 63, "Output"]
}, Open  ]],
Cell[14274, 535, 113, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[14412, 542, 174, 4, 41, "Input"],
Cell[14589, 548, 73, 1, 63, "Output"]
}, Open  ]],
Cell[14677, 552, 54, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[14756, 556, 160, 3, 41, "Input"],
Cell[14919, 561, 73, 1, 63, "Output"]
}, Open  ]],
Cell[15007, 565, 70, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[15102, 569, 208, 5, 71, "Input"],
Cell[15313, 576, 73, 1, 63, "Output"]
}, Open  ]],
Cell[15401, 580, 73, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[15499, 584, 53, 1, 41, "Input"],
Cell[15555, 587, 38, 1, 41, "Output"]
}, Open  ]],
Cell[15608, 591, 191, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[15824, 600, 171, 4, 41, "Input"],
Cell[15998, 606, 73, 1, 63, "Output"]
}, Open  ]],
Cell[16086, 610, 54, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[16165, 614, 97, 2, 41, "Input"],
Cell[16265, 618, 51, 1, 63, "Output"]
}, Open  ]],
Cell[16331, 622, 175, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[16531, 631, 101, 2, 61, "Input"],
Cell[16635, 635, 119, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16791, 642, 115, 3, 61, "Input"],
Cell[16909, 647, 119, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17065, 654, 103, 2, 61, "Input"],
Cell[17171, 658, 119, 2, 59, "Output"]
}, Open  ]],
Cell[17305, 663, 59, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[17389, 667, 83, 1, 41, "Input"],
Cell[17475, 670, 45, 1, 41, "Output"]
}, Open  ]],
Cell[17535, 674, 147, 5, 45, "Text"],
Cell[17685, 681, 295, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[18005, 691, 153, 3, 62, "Input"],
Cell[18161, 696, 128, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18326, 703, 160, 3, 62, "Input"],
Cell[18489, 708, 120, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18646, 715, 155, 3, 62, "Input"],
Cell[18804, 720, 113, 2, 59, "Output"]
}, Open  ]],
Cell[18932, 725, 65, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[19022, 729, 154, 3, 67, "Input"],
Cell[19179, 734, 84, 1, 59, "Output"]
}, Open  ]],
Cell[19278, 738, 112, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[19415, 745, 83, 1, 41, "Input"],
Cell[19501, 748, 37, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19587, 755, 249, 11, 62, "Subsubsection"],
Cell[19839, 768, 484, 12, 93, "Text"],
Cell[20326, 782, 237, 4, 93, "Text"],
Cell[20566, 788, 120, 2, 45, "Text"],
Cell[20689, 792, 330, 5, 117, "Text"],
Cell[21022, 799, 307, 5, 93, "Text"],
Cell[21332, 806, 256, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21625, 817, 211, 9, 61, "Subsubsection"],
Cell[21839, 828, 44, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[21908, 832, 97, 2, 44, "Input"],
Cell[22008, 836, 55, 1, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22100, 842, 78, 1, 44, "Input"],
Cell[22181, 845, 55, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22273, 851, 78, 1, 44, "Input"],
Cell[22354, 854, 92, 1, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22483, 860, 78, 1, 44, "Input"],
Cell[22564, 863, 49, 1, 63, "Output"]
}, Open  ]],
Cell[22628, 867, 161, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[22814, 876, 130, 2, 41, "Input"],
Cell[22947, 880, 51, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23035, 886, 137, 2, 41, "Input"],
Cell[23175, 890, 51, 1, 63, "Output"]
}, Open  ]],
Cell[23241, 894, 151, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[23417, 903, 93, 1, 41, "Input"],
Cell[23513, 906, 91, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23641, 912, 93, 1, 41, "Input"],
Cell[23737, 915, 100, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23874, 922, 93, 1, 41, "Input"],
Cell[23970, 925, 89, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24096, 931, 53, 1, 41, "Input"],
Cell[24152, 934, 84, 1, 59, "Output"]
}, Open  ]],
Cell[24251, 938, 88, 2, 45, "Text"],
Cell[24342, 942, 244, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[24611, 952, 338, 8, 94, "Input"],
Cell[24952, 962, 175, 3, 74, "Output"]
}, Open  ]],
Cell[25142, 968, 47, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[25214, 972, 91, 1, 44, "Input"],
Cell[25308, 975, 51, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25396, 981, 67, 1, 41, "Input"],
Cell[25466, 984, 37, 1, 41, "Output"]
}, Open  ]],
Cell[25518, 988, 323, 9, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25878, 1002, 222, 9, 61, "Subsubsection"],
Cell[26103, 1013, 328, 8, 93, "Text"],
Cell[26434, 1023, 280, 5, 93, "Text"],
Cell[26717, 1030, 117, 3, 45, "Text"],
Cell[26837, 1035, 166, 3, 48, "NumberedEquation"],
Cell[27006, 1040, 490, 13, 117, "Text"],
Cell[27499, 1055, 153, 5, 45, "Text"],
Cell[27655, 1062, 353, 6, 44, "NumberedEquation"],
Cell[28011, 1070, 300, 11, 45, "Text"],
Cell[28314, 1083, 554, 17, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28905, 1105, 191, 9, 61, "Subsubsection"],
Cell[29099, 1116, 271, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[29395, 1129, 152, 3, 66, "Input"],
Cell[29550, 1134, 119, 3, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29706, 1142, 152, 3, 66, "Input"],
Cell[29861, 1147, 134, 4, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30032, 1156, 152, 3, 66, "Input"],
Cell[30187, 1161, 127, 3, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30351, 1169, 124, 3, 41, "Input"],
Cell[30478, 1174, 101, 2, 63, "Output"]
}, Open  ]],
Cell[30594, 1179, 182, 4, 69, "Text"],
Cell[30779, 1185, 378, 9, 93, "Text"],
Cell[31160, 1196, 168, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[31353, 1205, 43, 1, 41, "Input"],
Cell[31399, 1208, 175, 3, 74, "Output"]
}, Open  ]],
Cell[31589, 1214, 126, 3, 69, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31764, 1223, 149, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[31938, 1234, 210, 9, 61, "Subsubsection"],
Cell[32151, 1245, 263, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[32439, 1255, 99, 2, 41, "Input"],
Cell[32541, 1259, 868, 15, 278, "Output"]
}, Open  ]],
Cell[33424, 1277, 110, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[33559, 1284, 121, 3, 41, "Input"],
Cell[33683, 1289, 380, 7, 178, "Output"]
}, Open  ]],
Cell[34078, 1299, 281, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[34384, 1312, 86, 1, 41, "Input"],
Cell[34473, 1315, 205, 4, 66, "Output"]
}, Open  ]],
Cell[34693, 1322, 259, 7, 69, "Text"],
Cell[34955, 1331, 482, 11, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35474, 1347, 250, 12, 61, "Subsubsection"],
Cell[35727, 1361, 908, 23, 165, "Text"],
Cell[36638, 1386, 341, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[37004, 1399, 86, 1, 66, "Input"],
Cell[37093, 1402, 231, 4, 66, "Output"]
}, Open  ]],
Cell[37339, 1409, 328, 7, 93, "Text"],
Cell[37670, 1418, 378, 12, 78, "Text"],
Cell[38051, 1432, 516, 11, 125, "Text"],

Cell[CellGroupData[{
Cell[38592, 1447, 296, 5, 143, "Input"],
Cell[38891, 1454, 2887, 97, 131, "Output"]
}, Open  ]],
Cell[41793, 1554, 271, 8, 69, "Text"],
Cell[42067, 1564, 254, 5, 93, "Text"],
Cell[42324, 1571, 216, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[42565, 1581, 109, 2, 43, "Input"],
Cell[42677, 1585, 251, 4, 69, "Output"]
}, Open  ]],
Cell[42943, 1592, 622, 14, 125, "Text"],
Cell[43568, 1608, 47, 0, 45, "Text"],
Cell[43618, 1610, 345, 8, 141, "Text"],
Cell[43966, 1620, 214, 4, 93, "Text"],
Cell[44183, 1626, 1079, 29, 213, "Text"],
Cell[45265, 1657, 190, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45492, 1666, 206, 9, 61, "Subsubsection"],
Cell[45701, 1677, 293, 7, 93, "Text"],
Cell[45997, 1686, 267, 5, 93, "Text"],
Cell[46267, 1693, 66, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[46358, 1697, 181, 4, 74, "Input"],
Cell[46542, 1703, 716, 25, 95, "Output"]
}, Open  ]],
Cell[47273, 1731, 72, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[47370, 1735, 119, 2, 72, "Input"],
Cell[47492, 1739, 813, 28, 95, "Output"]
}, Open  ]],
Cell[48320, 1770, 158, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[48503, 1779, 160, 3, 72, "Input"],
Cell[48666, 1784, 633, 22, 91, "Output"]
}, Open  ]],
Cell[49314, 1809, 123, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[49462, 1816, 160, 3, 66, "Input"],
Cell[49625, 1821, 3538, 111, 189, "Output"]
}, Open  ]],
Cell[53178, 1935, 120, 3, 45, "Text"],
Cell[53301, 1940, 135, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[53461, 1947, 219, 5, 122, "Input"],
Cell[53683, 1954, 415, 11, 153, "Output"]
}, Open  ]],
Cell[54113, 1968, 168, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[54306, 1977, 172, 3, 66, "Input"],
Cell[54481, 1982, 1873, 59, 111, "Output"]
}, Open  ]],
Cell[56369, 2044, 242, 4, 93, "Text"],
Cell[56614, 2050, 185, 5, 45, "Text"],
Cell[56802, 2057, 731, 14, 330, "NumberedEquation",
  CellTags->"squareroots"],
Cell[57536, 2073, 243, 3, 93, "Text"],
Cell[57782, 2078, 218, 6, 69, "Text"],
Cell[58003, 2086, 470, 9, 185, "NumberedEquation"],
Cell[58476, 2097, 96, 2, 45, "Text"],
Cell[58575, 2101, 415, 8, 117, "Text"],
Cell[58993, 2111, 469, 15, 93, "Text"],
Cell[59465, 2128, 210, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59712, 2137, 194, 9, 61, "Subsubsection"],
Cell[59909, 2148, 128, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[60062, 2156, 43, 1, 41, "Input"],
Cell[60108, 2159, 71, 1, 35, "Print"]
}, Open  ]],
Cell[60194, 2163, 270, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[60489, 2174, 172, 3, 216, "Input"],
Cell[60664, 2179, 43, 1, 41, "Output"]
}, Open  ]],
Cell[60722, 2183, 112, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[60859, 2190, 90, 1, 41, "Input"],
Cell[60952, 2193, 276, 7, 108, "Output"]
}, Open  ]],
Cell[61243, 2203, 233, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[61501, 2214, 42, 1, 41, "Input"],
Cell[61546, 2217, 36, 1, 41, "Output"]
}, Open  ]],
Cell[61597, 2221, 565, 15, 117, "Text"],
Cell[62165, 2238, 226, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[62416, 2248, 232, 4, 78, "Input"],
Cell[62651, 2254, 2627, 66, 83, "Output"]
}, Open  ]],
Cell[65293, 2323, 227, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[65545, 2334, 259, 5, 174, "Input"],
Cell[65807, 2341, 2630, 66, 371, "Output"]
}, Open  ]],
Cell[68452, 2410, 218, 6, 69, "Text"],
Cell[68673, 2418, 168, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[68866, 2427, 293, 5, 190, "Input"],
Cell[69162, 2434, 1866, 48, 260, "Output"]
}, Open  ]],
Cell[71043, 2485, 118, 3, 45, "Text"],
Cell[71164, 2490, 111, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[71300, 2497, 100, 2, 66, "Input"],
Cell[71403, 2501, 40, 1, 41, "Output"]
}, Open  ]],
Cell[71458, 2505, 124, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[71607, 2512, 121, 3, 66, "Input"],
Cell[71731, 2517, 40, 1, 41, "Output"]
}, Open  ]],
Cell[71786, 2521, 123, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[71934, 2528, 155, 4, 66, "Input"],
Cell[72092, 2534, 40, 1, 41, "Output"]
}, Open  ]],
Cell[72147, 2538, 476, 9, 117, "Text"],
Cell[72626, 2549, 242, 8, 69, "Text"],
Cell[72871, 2559, 37, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[72933, 2563, 58, 1, 66, "Input"],
Cell[72994, 2566, 35, 1, 41, "Output"]
}, Open  ]],
Cell[73044, 2570, 542, 16, 117, "Text"],
Cell[73589, 2588, 524, 14, 117, "Text"],
Cell[74116, 2604, 840, 22, 165, "Text"],
Cell[74959, 2628, 280, 8, 69, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75300, 2643, 100, 5, 76, "Section"],
Cell[75403, 2650, 112, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[75540, 2659, 71, 1, 41, "Input"],
Cell[75614, 2662, 97, 2, 41, "Output"]
}, Open  ]],
Cell[75726, 2667, 54, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[75805, 2671, 43, 1, 41, "Input"],
Cell[75851, 2674, 54, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75954, 2681, 30, 0, 80, "Subtitle"],
Cell[75987, 2683, 258, 8, 93, "Text",
  CellTags->"[Bill1989]"],
Cell[76248, 2693, 320, 7, 93, "Text",
  CellTags->"[GKHKR1974]"],
Cell[76571, 2702, 337, 11, 93, "Text",
  CellTags->"[Haw1995]"],
Cell[76911, 2715, 242, 7, 93, "Text",
  CellTags->"[Oli1995]"],
Cell[77156, 2724, 220, 6, 69, "Text",
  CellTags->"[Sme1950]"],
Cell[77379, 2732, 316, 7, 93, "Text",
  CellTags->"[SRGT1993]"],
Cell[77698, 2741, 281, 9, 93, "Text",
  CellTags->"[Wol1997]"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

